@@ -22,12 +22,12 @@
 #include <QPointer>
 #include <qtimer.h>
 #include <KActionCollection>
-#include <klocale.h>
+#include <KLocalizedString>
 #include <knotification.h>
-#include <kinputdialog.h>
+#include <qinputdialog.h>
 #include <krandom.h>
 #include <ktoggleaction.h>
-#include <kicon.h>
+#include <QIcon>
 
 #include "kopeteuiglobal.h"
 #include "kopetemetacontact.h"
@@ -41,14 +41,13 @@
 #include "contactmanager.h"
 #include "oscarstatusmanager.h"
 
-
 ICQContact::ICQContact( Kopete::Account* account, const QString &name, Kopete::MetaContact *parent,
 						const QString& icon )
 : ICQContactBase( account, name, parent, icon )
 {
 	m_requestingInfo = InfoNone;
 	mProtocol = static_cast<ICQProtocol *>(protocol());
-	m_infoWidget = 0L;
+	m_infoWidget = nullptr;
 
 	setPresenceTarget( Oscar::Presence( Oscar::Presence::Offline ) );
 
@@ -269,8 +268,8 @@ void ICQContact::loggedIn()
 
 void ICQContact::slotRequestAuth()
 {
-	QString reason = KInputDialog::getText( i18n("Request Authorization"),
-	                                        i18n("Reason for requesting authorization:"),
+    QString reason = QInputDialog::getText( nullptr, i18n("Request Authorization"),
+                                            i18n("Reason for requesting authorization:"), QLineEdit::Normal,
 	                                        i18n("Please authorize me so I can add you to my contact list") );
 	if ( !reason.isNull() )
 		mAccount->engine()->requestAuth( contactId(), reason );
@@ -345,7 +344,7 @@ void ICQContact::receivedLongInfo( const QString& contact )
 	if ( Oscar::normalize( contact ) != Oscar::normalize( contactId() ) )
 	{
 		if ( m_infoWidget )
-			m_infoWidget->delayedDestruct();
+			m_infoWidget->deleteLater();
 		return;
 	}
 
@@ -527,7 +526,6 @@ void ICQContact::gotIM(OscarSocket::OscarMessageType /*type*/, const QString &me
 	manager(true)->appendMessage(msg);
 }
 
-
 void ICQContact::slotSendMsg(Kopete::Message& message, Kopete::ChatSession *)
 {
 	if (message.plainBody().isEmpty()) // no text, do nothing
@@ -561,36 +559,36 @@ bool ICQContact::isReachable()
 	return account()->isConnected();
 }
 
-QList<KAction*> *ICQContact::customContextMenuActions()
+QList<QAction*> *ICQContact::customContextMenuActions()
 {
-	QList<KAction*> *actions = new QList<KAction*>();
+	QList<QAction*> *actions = new QList<QAction*>();
 
-	actionRequestAuth = new KAction( i18n("&Request Authorization"), this );
+	actionRequestAuth = new QAction( i18n("&Request Authorization"), this );
         //, "actionRequestAuth");
-	actionRequestAuth->setIcon( KIcon( "mail-reply-sender" ) );
-	QObject::connect( actionRequestAuth, SIGNAL(triggered(bool)), this, SLOT(slotRequestAuth()) );
+    actionRequestAuth->setIcon( QIcon::fromTheme(QStringLiteral("mail-reply-sender")) );
+	QObject::connect(actionRequestAuth, &QAction::triggered, this, &ICQContact::slotRequestAuth);
 
-	actionSendAuth = new KAction( i18n("&Grant Authorization"), this );
+	actionSendAuth = new QAction( i18n("&Grant Authorization"), this );
         //, "actionSendAuth");
-	actionSendAuth->setIcon( KIcon( "mail-forward" ) );
-	QObject::connect( actionSendAuth, SIGNAL(triggered(bool)), this, SLOT(slotSendAuth()) );
+    actionSendAuth->setIcon( QIcon::fromTheme(QStringLiteral("mail-forward")) );
+	QObject::connect(actionSendAuth, &QAction::triggered, this, &ICQContact::slotSendAuth);
 
 	m_actionIgnore = new KToggleAction(i18n("&Ignore"), this );
         //, "actionIgnore");
-	QObject::connect( m_actionIgnore, SIGNAL(triggered(bool)), this, SLOT(slotIgnore()) );
+	QObject::connect(m_actionIgnore, &KToggleAction::triggered, this, &ICQContact::slotIgnore);
 
 	m_actionVisibleTo = new KToggleAction(i18n("Always &Visible To"), this );
         //, "actionVisibleTo");
-	QObject::connect( m_actionVisibleTo, SIGNAL(triggered(bool)), this, SLOT(slotVisibleTo()) );
+	QObject::connect(m_actionVisibleTo, &KToggleAction::triggered, this, &ICQContact::slotVisibleTo);
 
 	m_actionInvisibleTo = new KToggleAction(i18n("Always &Invisible To"), this );
         //, "actionInvisibleTo");
-	QObject::connect( m_actionInvisibleTo, SIGNAL(triggered(bool)), this, SLOT(slotInvisibleTo()) );
+	QObject::connect(m_actionInvisibleTo, &KToggleAction::triggered, this, &ICQContact::slotInvisibleTo);
 
-	m_selectEncoding = new KAction( i18n( "Select Encoding..." ), this );
+	m_selectEncoding = new QAction( i18n( "Select Encoding..." ), this );
         //, "changeEncoding" );
-	m_selectEncoding->setIcon( KIcon( "character-set" ) );
-	QObject::connect( m_selectEncoding, SIGNAL(triggered(bool)), this, SLOT(changeContactEncoding()) );
+    m_selectEncoding->setIcon( QIcon::fromTheme(QStringLiteral("character-set")) );
+	QObject::connect(m_selectEncoding, &QAction::triggered, this, &ICQContact::changeContactEncoding);
 
 	bool on = account()->isConnected();
 	if ( m_ssiItem.waitingAuth() )
@@ -627,7 +625,6 @@ QList<KAction*> *ICQContact::customContextMenuActions()
 	return actions;
 }
 
-
 void ICQContact::slotUserInfo()
 {
 	if ( m_infoWidget )
@@ -638,8 +635,8 @@ void ICQContact::slotUserInfo()
 	}
 
 	m_infoWidget = new ICQUserInfoWidget( this, Kopete::UI::Global::mainWidget() );
-	QObject::connect( m_infoWidget, SIGNAL(finished()), this, SLOT(closeUserInfoDialog()) );
-	QObject::connect( m_infoWidget, SIGNAL(okClicked()), this, SLOT(storeUserInfoDialog()) );
+	QObject::connect(m_infoWidget, &ICQUserInfoWidget::finished, this, &ICQContact::closeUserInfoDialog);
+	// QObject::connect(m_infoWidget, &ICQUserInfoWidget::okClicked, this, &ICQContact::storeUserInfoDialog);
 	m_infoWidget->show();
 }
 
@@ -655,8 +652,8 @@ void ICQContact::storeUserInfoDialog()
 void ICQContact::closeUserInfoDialog()
 {
 	QObject::disconnect( this, 0, m_infoWidget, 0 );
-	m_infoWidget->delayedDestruct();
-	m_infoWidget = 0L;
+	m_infoWidget->deleteLater();
+	m_infoWidget = nullptr;
 }
 
 void ICQContact::slotIgnore()
@@ -686,7 +683,7 @@ void ICQContact::slotReadAwayMessage()
 		awayMessageDialog = new ICQReadAway(this, 0L, "awayMessageDialog");
 		if(!awayMessageDialog)
 			return;
-		QObject::connect(awayMessageDialog, SIGNAL(closing()), this, SLOT(slotCloseAwayMessageDialog()));
+		QObject::connect(awayMessageDialog, &ICQReadAway::closing, this, &ICQContact::slotCloseAwayMessageDialog);
 		awayMessageDialog->show();
 	}
 	else
@@ -695,21 +692,18 @@ void ICQContact::slotReadAwayMessage()
 	}
 }
 
-
 void ICQContact::slotCloseAwayMessageDialog()
 {
-	awayMessageDialog->delayedDestruct();
-	awayMessageDialog = 0L;
+	awayMessageDialog->deleteLater();
+	awayMessageDialog = nullptr;
 }
 
-
 const QString ICQContact::awayMessage()
 {
 	kDebug(14150) <<  property(mProtocol->statusMessage).value().toString();
 	return property(mProtocol->statusMessage).value().toString();
 }
 
-
 void ICQContact::setAwayMessage(const QString &message)
 {
 	/*kDebug(14150) <<
@@ -718,7 +712,6 @@ void ICQContact::setAwayMessage(const QString &message)
 	emit awayMessageChanged();
 }
 
-
 void ICQContact::slotUpdGeneralInfo(const int seq, const ICQGeneralUserInfo &inf)
 {
 	// compare reply's sequence with the one we sent with our last request
@@ -762,7 +755,6 @@ void ICQContact::slotUpdGeneralInfo(const int seq, const ICQGeneralUserInfo &inf
 	incUserInfoCounter();
 }
 
-
 void ICQContact::slotSnacFailed(WORD snacID)
 {
 	if (userinfoRequestSequence != 0)
@@ -790,5 +782,3 @@ void ICQContact::slotVisibleTo()
 	setVisibleTo(actionVisibleTo->isChecked(), true);
 }
 #endif
-#include "icqcontact.moc"
-//kate: indent-mode csands; tab-width 4; replace-tabs off; space-indent off;
